@@ -1,15 +1,17 @@
+import typing as ty
 from functools import update_wrapper
 
 from django.contrib import admin
 from django.contrib.admin.utils import unquote
-from django.http import HttpResponse
+from django.http import HttpRequest, HttpResponse
 from django.views import View
 
 
 def wrap_model_instance_admin_view(
     model_admin: admin.ModelAdmin,
-    view: View,
-) -> HttpResponse:
+    view: ty.Type[View],
+    **view_kwargs,
+) -> ty.Callable[[HttpRequest, str, ...], HttpResponse]:
     """Wraps view to use at instance admin pages."""
 
     def wrap():
@@ -26,6 +28,7 @@ def wrap_model_instance_admin_view(
                 view.as_view(
                     model_admin=model_admin,
                     instance=instance,
+                    **view_kwargs,
                 )
             )(request, **kwargs)
 
@@ -36,15 +39,17 @@ def wrap_model_instance_admin_view(
 
 def wrap_model_list_admin_view(
     model_admin: admin.ModelAdmin,
-    view: View,
-) -> HttpResponse:
+    view: ty.Type[View],
+    **view_kwargs,
+) -> ty.Callable[[HttpRequest, ...], HttpResponse]:
     """Wraps view to use at models list admin pages."""
 
     def wrap():
-        def wrapper(request, **kwargs):
+        def wrapper(request: HttpRequest, **kwargs) -> HttpResponse:
             return model_admin.admin_site.admin_view(
                 view.as_view(
                     model_admin=model_admin,
+                    **view_kwargs,
                 )
             )(request, **kwargs)
 
